# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: manager.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\rmanager.proto\x12\x05proto\x1a\x1bgoogle/protobuf/empty.proto"J\n\x0fSendDataRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1d\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\r.proto.Format\x12\x0c\n\x04\x64\x61ta\x18\n \x01(\x0c"f\n\x0fSendFileRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1d\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\r.proto.Format\x12\x0c\n\x04path\x18\n \x01(\t\x12\x11\n\x04name\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name"O\n\x15SendJSONSchemaRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\x11\n\x04name\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name"7\n\x18SendColumnsSchemaRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t"t\n\x1aReportDataUnitStateRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0f\n\x07healthy\x18\x04 \x01(\x08\x12\x11\n\x04name\x18\x05 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name*T\n\x06\x46ormat\x12\x12\n\x0e\x46ORMAT_UNKNOWN\x10\x00\x12\x0f\n\x0b\x46ORMAT_JSON\x10\x01\x12\x11\n\rFORMAT_STRING\x10\x02\x12\x12\n\x0e\x46ORMAT_PARQUET\x10\x03\x32\xe9\x02\n\x07Manager\x12:\n\x08SendData\x12\x16.proto.SendDataRequest\x1a\x16.google.protobuf.Empty\x12:\n\x08SendFile\x12\x16.proto.SendFileRequest\x1a\x16.google.protobuf.Empty\x12\x46\n\x0eSendJSONSchema\x12\x1c.proto.SendJSONSchemaRequest\x1a\x16.google.protobuf.Empty\x12L\n\x11SendColumnsSchema\x12\x1f.proto.SendColumnsSchemaRequest\x1a\x16.google.protobuf.Empty\x12P\n\x13ReportDataUnitState\x12!.proto.ReportDataUnitStateRequest\x1a\x16.google.protobuf.EmptyB\tZ\x07.;protob\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "manager_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\007.;proto"
    _globals["_FORMAT"]._serialized_start = 489
    _globals["_FORMAT"]._serialized_end = 573
    _globals["_SENDDATAREQUEST"]._serialized_start = 53
    _globals["_SENDDATAREQUEST"]._serialized_end = 127
    _globals["_SENDFILEREQUEST"]._serialized_start = 129
    _globals["_SENDFILEREQUEST"]._serialized_end = 231
    _globals["_SENDJSONSCHEMAREQUEST"]._serialized_start = 233
    _globals["_SENDJSONSCHEMAREQUEST"]._serialized_end = 312
    _globals["_SENDCOLUMNSSCHEMAREQUEST"]._serialized_start = 314
    _globals["_SENDCOLUMNSSCHEMAREQUEST"]._serialized_end = 369
    _globals["_REPORTDATAUNITSTATEREQUEST"]._serialized_start = 371
    _globals["_REPORTDATAUNITSTATEREQUEST"]._serialized_end = 487
    _globals["_MANAGER"]._serialized_start = 576
    _globals["_MANAGER"]._serialized_end = 937
# @@protoc_insertion_point(module_scope)
