# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: source.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0csource.proto\x12\x05proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto"L\n\x0cStartRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12"\n\x07sources\x18\x02 \x03(\x0b\x32\x11.proto.DataSource\x12\x0c\n\x04name\x18\n \x01(\t"]\n\nDataSource\x12\n\n\x02id\x18\x01 \x01(\t\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\x04name\x18\n \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name"9\n\x0bStopRequest\x12*\n\x07Timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration".\n\rStatusMessage\x12\x1d\n\x06status\x18\x01 \x01(\x0e\x32\r.proto.Status"W\n\x0e\x44\x65tailsMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x11\n\x04name\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name"G\n\x0b\x44\x61taMessage\x12\x0f\n\x07manager\x18\x01 \x01(\r\x12\'\n\x06source\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct".\n\x03Run\x12\'\n\x06source\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct"Y\n\rConfigMessage\x12(\n\rSourcesConfig\x18\x01 \x03(\x0b\x32\x11.proto.DataSource\x12\x1e\n\nRunsConfig\x18\x02 \x03(\x0b\x32\n.proto.Run"J\n\x11ValidationMessage\x12\r\n\x05valid\x18\x01 \x01(\x08\x12&\n\x06\x65rrors\x18\x02 \x03(\x0b\x32\x16.proto.ValidationError"4\n\x0fValidationError\x12\x10\n\x08location\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t""\n\x14StartedStreamMessage\x12\n\n\x02ID\x18\x01 \x01(\t"\x1f\n\x11StopStreamMessage\x12\n\n\x02ID\x18\x01 \x01(\t*T\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x10\n\x0cSTATUS_READY\x10\x01\x12\x12\n\x0eSTATUS_RUNNING\x10\x02\x12\x10\n\x0cSTATUS_ERROR\x10\x03\x32\xad\x02\n\nBaseSource\x12\x34\n\x05Start\x12\x13.proto.StartRequest\x1a\x16.google.protobuf.Empty\x12\x32\n\x04Stop\x12\x12.proto.StopRequest\x1a\x16.google.protobuf.Empty\x12\x39\n\tGetStatus\x12\x16.google.protobuf.Empty\x1a\x14.proto.StatusMessage\x12;\n\nGetDetails\x12\x16.google.protobuf.Empty\x1a\x15.proto.DetailsMessage\x12=\n\x0b\x43heckConfig\x12\x14.proto.ConfigMessage\x1a\x18.proto.ValidationMessage2?\n\x06Source\x12\x35\n\x07GetData\x12\x12.proto.DataMessage\x1a\x16.google.protobuf.Empty2\x91\x01\n\x0fStreamingSource\x12>\n\x0bStartStream\x12\x12.proto.DataMessage\x1a\x1b.proto.StartedStreamMessage\x12>\n\nStopStream\x12\x18.proto.StopStreamMessage\x1a\x16.google.protobuf.EmptyB\tZ\x07.;protob\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "source_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\007.;proto"
    _globals["_STATUS"]._serialized_start = 894
    _globals["_STATUS"]._serialized_end = 978
    _globals["_STARTREQUEST"]._serialized_start = 114
    _globals["_STARTREQUEST"]._serialized_end = 190
    _globals["_DATASOURCE"]._serialized_start = 192
    _globals["_DATASOURCE"]._serialized_end = 285
    _globals["_STOPREQUEST"]._serialized_start = 287
    _globals["_STOPREQUEST"]._serialized_end = 344
    _globals["_STATUSMESSAGE"]._serialized_start = 346
    _globals["_STATUSMESSAGE"]._serialized_end = 392
    _globals["_DETAILSMESSAGE"]._serialized_start = 394
    _globals["_DETAILSMESSAGE"]._serialized_end = 481
    _globals["_DATAMESSAGE"]._serialized_start = 483
    _globals["_DATAMESSAGE"]._serialized_end = 554
    _globals["_RUN"]._serialized_start = 556
    _globals["_RUN"]._serialized_end = 602
    _globals["_CONFIGMESSAGE"]._serialized_start = 604
    _globals["_CONFIGMESSAGE"]._serialized_end = 693
    _globals["_VALIDATIONMESSAGE"]._serialized_start = 695
    _globals["_VALIDATIONMESSAGE"]._serialized_end = 769
    _globals["_VALIDATIONERROR"]._serialized_start = 771
    _globals["_VALIDATIONERROR"]._serialized_end = 823
    _globals["_STARTEDSTREAMMESSAGE"]._serialized_start = 825
    _globals["_STARTEDSTREAMMESSAGE"]._serialized_end = 859
    _globals["_STOPSTREAMMESSAGE"]._serialized_start = 861
    _globals["_STOPSTREAMMESSAGE"]._serialized_end = 892
    _globals["_BASESOURCE"]._serialized_start = 981
    _globals["_BASESOURCE"]._serialized_end = 1282
    _globals["_SOURCE"]._serialized_start = 1284
    _globals["_SOURCE"]._serialized_end = 1347
    _globals["_STREAMINGSOURCE"]._serialized_start = 1350
    _globals["_STREAMINGSOURCE"]._serialized_end = 1495
# @@protoc_insertion_point(module_scope)
